from __future__ import annotations

from enum import Enum


class WeightUnit(Enum):
    GSM = "GSM"
    LBS_TEXT = "LBS_TEXT"
    LBS_COVER = "LBS_COVER"
    MICRONS = "MICRONS"
    SHIROKU_BAN = "SHIROKU_BAN"
